import { Entity, Column, PrimaryGeneratedColumn, BeforeInsert } from 'typeorm';
import * as bcrypt from 'bcryptjs';
import * as jwt from 'jsonwebtoken';

@Entity('Person')
export class PersonEntity {
    @PrimaryGeneratedColumn('uuid') id: string;
    @Column({type: 'text', unique: true}) name: string;
    @Column('text') password: string;

    @BeforeInsert()
    async hashPassword() {
        this.password = await bcrypt.hash(this.password, 10);
    }

    tokenObject() {
        const {name, token} = this;
        return {name, token};
    }

    async comparePassword(attempt: string) {
        return await bcrypt.compareSync(attempt, this.password);
    }

    private get token() {
        const {id, name} = this;
        return jwt.sign({
            id, name
        },
        process.env.SECRET,
        { expiresIn: '15min'},
        );
    }
}